"use client";

import { useEffect, useState } from "react";

type User = {
  id: number;
  first_name: string;
  last_name: string;
  email: string;
  gender: string;
  phone: string;
};

const Home = () => {
  const [data, setData] = useState<User[]>([]);
  const [deleteSuccessMessage, setDeleteSuccessMessage] = useState("");

  useEffect(() => {
    const fetchData = async () => {
      try {
        const res = await fetch("http://localhost:10091/users");
        const responseData = await res.json();
        setData(responseData.info);
      } catch (err) {
        console.error(err);
      }
    };
    fetchData();
  }, []);

  const handleDelete = async (id: number) => {
    try {
      await fetch(`http://localhost:10091/users/${id}`, {
        method: "DELETE"
      });
      setData(data.filter((user) => user.id !== id)); // Remove the deleted user from the state
      setDeleteSuccessMessage("Delete successful");
      // Automatically hide the delete success message after 1 minute
      setTimeout(() => {
        setDeleteSuccessMessage("");
      }, 60000);
    } catch (err) {
      console.error(err);
    }
  };

  return (
    <main>
      <div>
        <h1>Next.js - HTTP GET and DELETE HTTP calls example</h1>
        {deleteSuccessMessage && <div>{deleteSuccessMessage}</div>}
        <table>
          <thead>
            <tr>
              <th>first name</th>
              <th>last name</th>
              <th>email address</th>
              <th>gender</th>
              <th>phone number</th>
              <th>Action</th> {/* Add a column for delete button */}
            </tr>
          </thead>
          <tbody>
            {data.map((user) => (
              <tr key={user.id}>
                <td>{user.first_name}</td>
                <td>{user.last_name}</td>
                <td>{user.email}</td>
                <td>{user.gender}</td>
                <td>{user.phone}</td>
                <td>
                  <button onClick={() => handleDelete(user.id)}>Delete</button>{" "}
                  {/* Add delete button */}
                </td>
              </tr>
            ))}
          </tbody>
        </table>
      </div>
    </main>
  );
};

export default Home;
